##  Editing a Diagram Template
Use editing when you want to change an existing template. For example, to update its relations, drill-downs, views, labels, or layout.
  1. Go to the Diagram Templates page.
  2. Select the template you want to change.
  3. Choose Edit Template.


![Diagram template editor showing connected application, organization, and business capability nodes with "Edit Template" highlighted.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiobd827deddca643f8b5ebc16566ee714e_LowRes.png)
Editing a Template
